@@ -7,8 +7,12 @@ unless you have installed `https://github.com/novafacing/ubuntu-rc`
 
 from logging import CRITICAL
 from pwnlib.context import context
-from pwnlib.log import console
+from pwnlib.log import console, rootlogger
 
 
 context.terminal = ["kitty", "-e", "sh", "-c"]  # pylint: disable=assigning-non-slot
+
 console.setLevel(CRITICAL)
+
+for h in rootlogger.handlers:
+    rootlogger.removeHandler(h)
