@@ -4,6 +4,7 @@ Pwntools wrapper and convenience things!
 
 
 from enum import Enum
+from logging import getLogger
 from pathlib import Path
 from typing import Any, Dict, Optional, Tuple, Union, cast
 
@@ -13,6 +14,8 @@ from pwnlib.tubes.process import process
 from pwnlib.tubes.remote import remote
 from pwnlib.tubes.tube import tube
 
+l = getLogger(__file__)
+
 
 class PWMode(str, Enum):
     """
@@ -153,18 +156,18 @@ class PW:
 
         self.elf: Optional[ELF] = None  # type: ignore
         self.libc: Optional[ELF] = None  # type: ignore
-        self.libs: Optional[Dict[str, ELF]] = None  # type: ignore
+        self.libs: Dict[str, ELF] = {}
 
         if self.binary is not None and not self.binary.is_file():
             raise FileNotFoundError(f"{self.binary} is not a file")
         elif self.binary is not None:
-            self.elf = ELF(str(self.binary.resolve()))
+            self.elf = ELF(str(self.binary.resolve()), checksec=False)
             self.libc = self.elf.libc
             self.libs = {}
 
             for lib in self.elf.libs:
                 if (lname := Path(lib).name) != self.binary.name:
-                    self.libs[lname] = ELF(lib)
+                    self.libs[lname] = ELF(lib, checksec=False)
 
         self.addr = addr
         self.port = port
@@ -180,6 +183,8 @@ class PW:
         elif self.p is not None and self.r is not None:
             raise Exception("Cannot open both local and remote tubes.")
 
+        self.checksec()
+
     def open_tubes(self) -> Tuple[Optional[tube], Optional[tube]]:  # type: ignore
         """
         Open process and remote tubes based on the given mode.
@@ -222,6 +227,22 @@ class PW:
 
     # Convenience methods
 
+    def checksec(self) -> None:
+        """
+        Check the security of the binary.
+        """
+        if self.elf is not None:
+            for lib, elf in self.libs.items():
+                if not elf != self.elf:
+                    l.info(f"Checksec info for {lib}:")
+                    for ln in elf.checksec().splitlines():
+                        l.info(ln)
+                l.info(f"Checksec info for main object {self.binary.name}:")
+                for ln in self.elf.checksec().splitlines():
+                    l.info(ln)
+
+    # Printer proxy methods
+
     def precvall(self) -> bytes:
         """
         Receive all data from the remote tube and print it.
